from qqai.classes import *


class SceneR(QQAIPicRecognitionClass):
    """场景识别"""
    api = 'https://api.ai.qq.com/fcgi-bin/vision/vision_scener'

class ObjectR(QQAIPicRecognitionClass):
    """物体识别"""
    api = 'https://api.ai.qq.com/fcgi-bin/vision/vision_objectr'

class Tag(QQAIPicClass):
    """图像标签识别"""
    api = 'https://api.ai.qq.com/fcgi-bin/image/image_tag'

class ImgToText(QQAIClass):
    """看图说话"""
    api = 'https://api.ai.qq.com/fcgi-bin/vision/vision_imgtotext'

    def make_params(self, image_param):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'image': self.get_base64(image_param),
                  'session_id': int(time.time()),
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_param):
        params = self.make_params(image_param)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class Fuzzy(QQAIPicClass):
    """模糊图片检测"""
    api = 'https://api.ai.qq.com/fcgi-bin/image/image_fuzzy'

class Food(QQAIPicClass):
    """美食图片识别"""
    api = 'https://api.ai.qq.com/fcgi-bin/image/image_food'

class Porn(QQAIPicClass):
    """智能鉴黄"""
    api = 'https://api.ai.qq.com/fcgi-bin/vision/vision_porn'

class Terrorism(QQAIPicClass):
    """暴恐图片识别"""
    api = 'https://api.ai.qq.com/fcgi-bin/image/image_terrorism'



from qqai.classes import *


class IDCardOCR(QQAIClass):
    """身份证OCR"""
    api = 'https://api.ai.qq.com/fcgi-bin/ocr/ocr_idcardocr'

    def make_params(self, image_param, cardtype):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'image': self.get_base64(image_param),
                  'card_type': cardtype,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_param, cardtype=0):
        params = self.make_params(image_param, cardtype)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class BCOCR(QQAIPicClass):
    """名片OCR"""
    api = 'https://api.ai.qq.com/fcgi-bin/ocr/ocr_bcocr'

class DriverLicenseOCR(QQAIClass):
    """行驶证驾驶证OCR"""
    api = 'https://api.ai.qq.com/fcgi-bin/ocr/ocr_driverlicenseocr'

    def make_params(self, image_param, license_type):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'image': self.get_base64(image_param),
                  'type': license_type,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_param, license_type=1):
        params = self.make_params(image_param, license_type)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class PlateOCR(QQAIPicOrURLClass):
    """车牌OCR"""
    api = 'https://api.ai.qq.com/fcgi-bin/ocr/ocr_plateocr'

class BizLicenseOCR(QQAIPicClass):
    """营业执照OCR"""
    api = 'https://api.ai.qq.com/fcgi-bin/ocr/ocr_bizlicenseocr'

class CreditCardOCR(QQAIPicClass):
    """银行卡OCR"""
    api = 'https://api.ai.qq.com/fcgi-bin/ocr/ocr_creditcardocr'

class GeneralOCR(QQAIPicClass):
    """通用OCR"""
    api = 'https://api.ai.qq.com/fcgi-bin/ocr/ocr_generalocr'

class HandwritingOCR(QQAIPicOrURLClass):
    """手写体OCR"""
    api = 'https://api.ai.qq.com/fcgi-bin/ocr/ocr_handwritingocr'



from qqai.classes import *

class AudioRecognitionEcho(QQAIClass):
    """语音识别-echo版"""
    api = 'https://api.ai.qq.com/fcgi-bin/aai/aai_asr'

    def make_params(self, audio_format, speech, rate=None):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'format': audio_format,
                  'speech': self.get_base64(speech),
                  }
        if rate is not None:
            params['rate'] = 16000
        params['sign'] = self.get_sign(params)
        return params

    def run(self, audio_format, speech, rate=None):
        params = self.make_params(audio_format, speech, rate)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result


import hashlib
import base64
from urllib import parse
import requests
import time
import json


class QQAIClass:
    headers = {'Content-Type': 'application/x-www-form-urlencoded'}
    mediaHeaders = {
        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/68.0.3440.75 Safari/537.36',
    }

    def __init__(self, app_id, app_key):
        self.app_id = app_id
        self.app_key = app_key

    def get_base64(self, media_param):
        """获取媒体的Base64字符串

        :param media_param 媒体URL或者媒体BufferedReader对象
        """
        if type(media_param) == str:
            media_data = requests.get(
                media_param, headers=self.mediaHeaders).content
        elif hasattr(media_param, 'read'):
            media_data = media_param.read()
        else:
            raise TypeError('media must be URL or BufferedReader')

        media = base64.b64encode(media_data).decode("utf-8")
        return media

    def get_sign(self, params):
        """获取签名
        """
        uri_str = ''
        for key in sorted(params.keys()):
            uri_str += '{}={}&'.format(key,
                                       parse.quote_plus(str(params[key]), safe=''))
        sign_str = uri_str + 'app_key=' + self.app_key

        hash_str = hashlib.md5(sign_str.encode('utf-8'))
        return hash_str.hexdigest().upper()

    def call_api(self, params, api=None):
        if api is None:
            api = self.api
        return requests.post(
            api, data=parse.urlencode(params).encode("utf-8"), headers=self.headers)

class QQAIPicClass(QQAIClass):
    def make_params(self, image_param):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'image': self.get_base64(image_param),
                 }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_param):
        params = self.make_params(image_param)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class QQAIPicRecognitionClass(QQAIClass):
    def make_params(self, image_param, api_format, topk):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'format': api_format,
                  'topk': topk,
                  'image': self.get_base64(image_param),
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_param, api_format=1, topk=5):
        params = self.make_params(image_param, api_format, topk)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class QQAIPicOrURLClass(QQAIPicClass):
    def make_params(self, image_param):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  }
        if type(image_param) == str:
            params['image_url'] = image_param
        elif hasattr(image_param, 'read'):
            image_data = image_param.read()
            image = base64.b64encode(image_data).decode("utf-8")
            params['image'] = image
        else:
            raise TypeError('image must be URL or BufferedReader')
        params['sign'] = self.get_sign(params)
        return params

class QQAIFaceClass(QQAIClass):
    def make_params(self, image_param, mode):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'image': self.get_base64(image_param),
                  'mode': mode,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_param, mode=1):
        params = self.make_params(image_param, mode)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class QQAIFacePersonClass(QQAIClass):
    def make_params(self, person_id):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'person_id': person_id,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, person_id):
        params = self.make_params(person_id)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class QQAITextUTF8Class(QQAIClass):
    def make_params(self, text):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'text': text,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, text):
        params = self.make_params(text)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class QQAITextGBKClass(QQAITextUTF8Class):

    def get_sign(self, params):
        """获取签名"""
        uri_str = ''
        for key in sorted(params.keys()):
            uri_str += '{}={}&'.format(key, parse.quote(str(params[key]),
                                                        encoding='gbk',
                                                        safe=''))
        sign_str = uri_str + 'app_key=' + self.app_key

        hash_str = hashlib.md5(sign_str.encode('gbk'))
        return hash_str.hexdigest().upper()

    def call_api(self, params, api=None):
        if api is None:
            api = self.api
        return requests.post(
            api, data=parse.urlencode(params, encoding='gbk').encode("gbk"),
            headers=self.headers)


from qqai.classes import *

class WordSeg(QQAITextGBKClass):
    """分词"""
    api = 'https://api.ai.qq.com/fcgi-bin/nlp/nlp_wordseg'

class WordPos(QQAITextGBKClass):
    """词性标注"""
    api = 'https://api.ai.qq.com/fcgi-bin/nlp/nlp_wordpos'

class WordNer(QQAITextGBKClass):
    """专有名词识别"""
    api = 'https://api.ai.qq.com/fcgi-bin/nlp/nlp_wordner'

class WordSyn(QQAITextGBKClass):
    """同义词识别"""
    api = 'https://api.ai.qq.com/fcgi-bin/nlp/nlp_wordsyn'

class WordCom(QQAITextUTF8Class):
    """意图成分识别"""
    api = 'https://api.ai.qq.com/fcgi-bin/nlp/nlp_wordcom'

class TextPolar(QQAITextUTF8Class):
    """情感分析识别"""
    api = 'https://api.ai.qq.com/fcgi-bin/nlp/nlp_textpolar'

class TextChat(QQAIClass):
    """基础闲聊"""
    api = 'https://api.ai.qq.com/fcgi-bin/nlp/nlp_textchat'

    def make_params(self, session, question):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'session': session,
                  'question': question,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, session, question):
        params = self.make_params(session, question)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result




from qqai.classes import *


class FaceCosmetic(QQAIClass):
    """人脸美妆"""
    api = 'https://api.ai.qq.com/fcgi-bin/ptu/ptu_facecosmetic'

    def make_params(self, image_param, cosmetic):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'cosmetic': cosmetic,
                  'image': self.get_base64(image_param),
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_param, cosmetic):
        params = self.make_params(image_param, cosmetic)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class FaceDecoration(QQAIClass):
    """人脸变妆"""
    api = 'https://api.ai.qq.com/fcgi-bin/ptu/ptu_facedecoration'

    def make_params(self, image_param, decoration):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'decoration': decoration,
                  'image': self.get_base64(image_param),
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_param, decoration):
        params = self.make_params(image_param, decoration)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class ImgFilterPitu(QQAIClass):
    """图片滤镜（天天P图）"""
    api = 'https://api.ai.qq.com/fcgi-bin/ptu/ptu_imgfilter'

    def make_params(self, image_param, pic_filter):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'filter': pic_filter,
                  'image': self.get_base64(image_param),
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_param, pic_filter):
        params = self.make_params(image_param, pic_filter)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class ImgFilterAILab(QQAIClass):
    """图片滤镜（AI Lab）"""
    api = 'https://api.ai.qq.com/fcgi-bin/vision/vision_imgfilter'

    def make_params(self, image_param, pic_filter):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'filter': pic_filter,
                  'image': self.get_base64(image_param),
                  'session_id': int(time.time()),
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_param, pic_filter):
        params = self.make_params(image_param, pic_filter)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class FaceMerge(QQAIClass):
    """人脸融合"""
    api = 'https://api.ai.qq.com/fcgi-bin/ptu/ptu_facemerge'

    def make_params(self, image_param, model):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'model': model,
                  'image': self.get_base64(image_param),
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_param, model):
        params = self.make_params(image_param, model)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class FaceSticker(QQAIClass):
    """大头贴"""
    api = 'https://api.ai.qq.com/fcgi-bin/ptu/ptu_facesticker'

    def make_params(self, image_param, sticker):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'sticker': sticker,
                  'image': self.get_base64(image_param),
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_param, sticker):
        params = self.make_params(image_param, sticker)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class FaceAge(QQAIPicClass):
    """颜龄检测"""
    api = 'https://api.ai.qq.com/fcgi-bin/ptu/ptu_faceage'



from qqai.classes import *

class TTSAILab(QQAIClass):
    """语音合成（AI Lab）"""
    api = 'https://api.ai.qq.com/fcgi-bin/aai/aai_tts'

    def make_params(self, text, speaker, audio_format, volume=0, speed=100,
                    aht=0, apc=58):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'text': text,
                  'speaker': speaker,
                  'format': audio_format,
                  'volume': volume,
                  'speed': speed,
                  'aht': aht,
                  'apc': apc,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, text, speaker, audio_format, volume=0, speed=100, aht=0,
            apc=58):
        params = self.make_params(text, speaker, audio_format, volume, speed,
                                  aht, apc)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class TTSYouTu(QQAIClass):
    """语音合成（优图）"""
    api = 'https://api.ai.qq.com/fcgi-bin/aai/aai_tta'

    def make_params(self, text, model_type=0, speed=0):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'text': text,
                  'model_type': model_type,
                  'speed': speed,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, text, model_type=0, speed=0):
        params = self.make_params(text, model_type, speed)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result


from qqai.classes import *

class DetectFace(QQAIFaceClass):
    """人脸检测与分析"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_detectface'

class DetectMultiFace(QQAIPicClass):
    """多人脸检测"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_detectmultiface'

class FaceCompare(QQAIClass):
    """人脸对比"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_facecompare'

    def make_params(self, image_a_param, image_b_param):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'image_a': self.get_base64(image_a_param),
                  'image_b': self.get_base64(image_b_param),
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_a_param, image_b_param):
        params = self.make_params(image_a_param, image_b_param)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class DetectCrossAgeFace(QQAIClass):
    """跨年龄人脸识别"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_detectcrossageface'

    def make_params(self, source_image_param, target_image_param):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'source_image': self.get_base64(source_image_param),
                  'target_image': self.get_base64(target_image_param),
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, source_image_param, target_image_param):
        params = self.make_params(source_image_param, target_image_param)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class FaceShape(QQAIFaceClass):
    """五官定位"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_faceshape'

class FaceIdentify(QQAIClass):
    """人脸识别"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_faceidentify'

    def make_params(self, image, group_id, topn):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'image': self.get_base64(image),
                  'group_id': group_id,
                  'topn': topn,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image, group_id, topn=9):
        params = self.make_params(image, group_id, topn)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class FaceVerify(QQAIClass):
    """人脸验证"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_faceverify'

    def make_params(self, image, person_id):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'image': self.get_base64(image),
                  'person_id': person_id,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image, person_id):
        params = self.make_params(image, person_id)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class NewPerson(QQAIClass):
    """个体创建"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_newperson'

    def make_params(self, group_ids, person_id, image, person_name, tag=None):
        """获取调用接口的参数"""
        if type(group_ids) == str:
            group_ids_param = group_ids
        else:
            group_ids_param = '|'.join(group_ids)
            # 这里是猜测。文档中疑似转义发生错误，留下反斜杠，之后的字符不见了
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'group_ids': group_ids_param,
                  'person_id': person_id,
                  'image': self.get_base64(image),
                  'person_name': person_name,
                  }
        if tag is not None:
            params['tag'] = tag
        params['sign'] = self.get_sign(params)
        return params

    def run(self, group_ids, person_id, image, person_name, tag=None):
        params = self.make_params(group_ids, person_id, image, person_name, tag)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class DelPerson(QQAIFacePersonClass):
    """删除个体"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_delperson'

class AddFace(QQAIClass):
    """个体创建"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_addface'

    def make_params(self, person_id, images, tag):
        """获取调用接口的参数"""
        if type(images) == str or hasattr(images, 'read'):
            images_param = self.get_base64(images)
        else:
            if len(images) > 5:
                raise ValueError('No more than 5 images input in one request')
            else:
                images_param = '|'.join(map(self.get_base64, images))
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'person_id': person_id,
                  'images': images_param,
                  'tag': tag,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, person_id, images, tag):
        params = self.make_params(person_id, images, tag)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class DelFace(QQAIClass):
    """删除人脸"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_delface'

    def make_params(self, person_id, face_ids):
        """获取调用接口的参数"""
        if type(face_ids) == str:
            face_ids_param = face_ids
        else:
            face_ids_param = '|'.join(face_ids)
            # 这里是猜测。文档中疑似转义发生错误，留下反斜杠，之后的字符不见了
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'person_id': person_id,
                  'face_ids': face_ids_param,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, person_id, face_ids):
        params = self.make_params(person_id, face_ids)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class SetInfo(QQAIClass):
    """设置信息"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_setinfo'

    def make_params(self, person_id, person_name=None, tag=None):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'person_id': person_id,
                  }
        if person_name is not None:
            params['person_name'] = person_name
        if tag is not None:
            params['tag'] = tag
        params['sign'] = self.get_sign(params)
        return params

    def run(self, person_id, person_name=None, tag=None):
        params = self.make_params(person_id, person_name, tag)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class GetInfo(QQAIFacePersonClass):
    """获取信息"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_getinfo'

class GetGroupIds(QQAIClass):
    """获取组列表"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_getgroupids'

    def make_params(self):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self):
        params = self.make_params()
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class GetPersonIds(QQAIClass):
    """获取个体列表"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_getpersonids'

    def make_params(self, group_id):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'group_id': group_id
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, group_id):
        params = self.make_params(group_id)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class GetFaceIds(QQAIClass):
    """获取人脸列表"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_getfaceids'

    def make_params(self, person_id):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'person_id': person_id
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, person_id):
        params = self.make_params(person_id)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class GetFaceInfo(QQAIClass):
    """获取人脸信息"""
    api = 'https://api.ai.qq.com/fcgi-bin/face/face_getfaceinfo'

    def make_params(self, face_id):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'person_id': face_id
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, face_id):
        params = self.make_params(face_id)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result


from qqai.classes import *


class TextTranslateAILab(QQAIClass):
    """文本翻译（AI Lab）"""
    api = 'https://api.ai.qq.com/fcgi-bin/nlp/nlp_texttrans'

    def make_params(self, text, translate_type=0):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'type': translate_type,
                  'text': text,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, text, translate_type=0):
        params = self.make_params(text, translate_type)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class TextTranslateFanyi(QQAIClass):
    """文本翻译（翻译君）"""
    api = 'https://api.ai.qq.com/fcgi-bin/nlp/nlp_texttranslate'

    def make_params(self, text, source='auto', target='auto'):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'text': text,
                  'source': source,
                  'target': target,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, text, source='auto', target='auto'):
        params = self.make_params(text, source, target)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class ImageTranslate(QQAIClass):
    """图片翻译"""
    api = 'https://api.ai.qq.com/fcgi-bin/nlp/nlp_imagetranslate'

    def make_params(self, image_param, scene, source='auto', target='auto'):
        """获取调用接口的参数"""
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'image': self.get_base64(image_param),
                  'session': int(time.time()),
                  'scene': scene,
                  'source': source,
                  'target': target,
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, image_param, scene, source='auto', target='auto'):
        params = self.make_params(image_param, scene, source, target)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result

class TextDetect(QQAIClass):
    """语种识别"""
    api = 'https://api.ai.qq.com/fcgi-bin/nlp/nlp_textdetect'

    def make_params(self, text, candidate_langs=None, force=0):
        """获取调用接口的参数"""
        if candidate_langs is None:
            candidate_langs = ['zh', 'en', 'jp', 'kr']
        if type(candidate_langs) == str:
            candidate_langs_param = candidate_langs
        else:
            candidate_langs_param = '|'.join(candidate_langs)
        params = {'app_id': self.app_id,
                  'time_stamp': int(time.time()),
                  'nonce_str': int(time.time()),
                  'text': text,
                  'candidate_langs': candidate_langs_param,
                  'force': force
                  }
        params['sign'] = self.get_sign(params)
        return params

    def run(self, text, candidate_langs=None, force=0):
        params = self.make_params(text, candidate_langs, force)
        response = self.call_api(params)
        result = json.loads(response.text)
        return result